package LoadTester.CPU;

import java.awt.*;
import java.awt.event.*;
import java.io.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.table.*;

public class Initializer extends JFrame{
  private final Dimension SIZE   = new Dimension( 310, 270 );
  private final int       dLoad1 = 100;
  private final int       dLoad2 = 10000;
  private TestThread tester;
  private JTable     tbResult;
  private int        arResult[];
  private boolean    canLoop;
  private JTextField tfLoad1;
  private JTextField tfLoad2;
  private JButton    bStart;
  private JButton    bStop;
  private JButton    bClear;
  private JButton    bSet;
  
  public static void main( String args[] ){
    Initializer ini = new Initializer("CPU Load Tester Initializer 1.0");
  }
  public Initializer( String title ){
    super( title );
    
    canLoop = true;

    JPanel pane = ( JPanel )getContentPane();
    pane.setLayout( new BorderLayout(4,4));
    JPanel p1 = new JPanel( new GridLayout(2,4,4,4) );

    arResult = new int[10];
    tbResult = new JTable( new DefaultTableModel( new String[]{"s()","(ms)"}, 10 ) );
    JScrollPane sp = new JScrollPane( tbResult );
    for(int i = 0; i < 10; i++){
      tbResult.setValueAt(String.valueOf(i+1),i,0);
      tbResult.setValueAt("",i,1);
      arResult[i] = 0;
    }
    DefaultTableCellRenderer d = (DefaultTableCellRenderer)tbResult.getCellRenderer(0,0);
    d.setHorizontalAlignment(SwingConstants.CENTER);

    tbResult.getTableHeader().setReorderingAllowed(false);
    tbResult.getColumnModel().getColumn(0).setMaxWidth(70);

    tfLoad1 = new JTextField( String.valueOf(dLoad1) );
    tfLoad2 = new JTextField( String.valueOf(dLoad2) );
    tfLoad1.setHorizontalAlignment(SwingConstants.RIGHT);
    tfLoad2.setHorizontalAlignment(SwingConstants.RIGHT);

    JLabel lb1 = new JLabel("Load 1", JLabel.CENTER);
    JLabel lb2 = new JLabel("Load 2", JLabel.CENTER);

    bStart  = new JButton( new StartAction() );
    bStop   = new JButton( new StopAction() );
    bClear  = new JButton( new ClearAction() );
    bSet    = new JButton( new SetAction() );

    bStop.setEnabled(false);
    bSet.setEnabled(false);

    p1.add(bStart);
    p1.add(bStop);
    p1.add(bClear);
    p1.add(bSet);
    p1.add(lb1);
    p1.add(tfLoad1);
    p1.add(lb2);
    p1.add(tfLoad2);

    pane.add( p1, BorderLayout.NORTH );
    pane.add( sp, BorderLayout.CENTER );
    
    setDefaultCloseOperation( JFrame.EXIT_ON_CLOSE );
    setSize( SIZE );
    setVisible( true );
  }
  class StartAction extends AbstractAction implements Runnable{
    public StartAction(){
      putValue( Action.NAME, "Jn");
    }
    public void actionPerformed( ActionEvent e ){
      Thread th = new Thread( this );
      th.start();
    }
    public void run(){
      int load1 = Integer.parseInt( tfLoad1.getText() );
      int load2 = Integer.parseInt( tfLoad2.getText() );
      tfLoad1.setText( String.valueOf(load1) );
      tfLoad2.setText( String.valueOf(load2) );
      bStart.setEnabled(false);
      bStop.setEnabled(true);
      canLoop = true;
      try{
        for( int i = 0 ; i < 10 ; i++ ){
          if( !canLoop )
            break;
          tester = new TestThread(load1,load2);
          tester.setPriority( Thread.MAX_PRIORITY );
          tester.start();
          tester.join();
          arResult[i] = tester.getTime();
          tbResult.setValueAt( String.valueOf( arResult[i] ), i, 1 );
        }
      }catch( Exception ex ){
      }
      if(canLoop){
        bSet.setEnabled(true);
      }else{
        bStart.setEnabled(true);
      }
      bStop.setEnabled(false);
    }
  }
  class StopAction extends AbstractAction{
    public StopAction(){
      putValue( Action.NAME, "~");
    }
    public void actionPerformed( ActionEvent e ){
      canLoop = false;
    }
  }
  class ClearAction extends AbstractAction{
    public ClearAction(){
      putValue( Action.NAME, "NA");
    }
    public void actionPerformed( ActionEvent e ){
      for(int i = 0; i < 10; i++){
        tbResult.setValueAt(String.valueOf(i+1),i,0);
        tbResult.setValueAt("",i,1);
        arResult[i] = 0;
      }
      bStart.setEnabled(true);
      bSet.setEnabled(false);
    }
  }
  class SetAction extends AbstractAction{
    public SetAction(){
      putValue( Action.NAME, "ݒ");
    }
    public void actionPerformed( ActionEvent e ){
      int av = 0;
      int rel1;
      int rel2;
      for(int i = 0 ; i < 10 ; i++)
        av += arResult[i];
      int l1 = Integer.parseInt( tfLoad1.getText() );
      int l2 = Integer.parseInt( tfLoad2.getText() );
      rel1 = l1;
      rel2 = l2 * 10000 / av;
      try{
        FileWriter fr = new FileWriter( "init.txt" );
        fr.write( String.valueOf(rel1) + "\n");
        fr.write( String.valueOf(rel2) + "\n");
        fr.close();
      }catch( Exception ex ){
      }
    }
  }
}
